export const colorLegend = (selection, props) => {
  const {
    title,
    spacing,
    colorScale,
    textOffset,
    circleRadius,
    backgroundRectWidth,
    selectedColorValue,
    onClick,
    height,
    width,
  } = props;
  
  const n = colorScale.domain().length
  const padding = circleRadius * 2;
  
  // Set Background
  const backgroundRect = selection.selectAll('rect').data([null]);
  backgroundRect.enter().append('rect')
    .attr('width', backgroundRectWidth)
    .attr('height', spacing * n + padding)
    .attr('fill', 'white')
    .attr('x', -padding)
    .attr('y', -padding)
    .attr('rx', circleRadius * 2)
    .attr('opacity', 0.8)
  
  // Set Title
  selection.append('text')
    .style('font-size', 20)
    .attr('class', 'title')
    .attr('y', 125)
    .attr('x', width - 93)
    .text(title);
  
  
  // Add selection with colors as data
  const groups = selection.selectAll('g')
    .data(colorScale.domain())
  groups.exit().remove();
  
  
  // Add Circles Group and Class Name
  const groupsEnter = groups.enter().append('g')
    .attr('class', 'colors');
  
  
  // Update Circle Groups
  groupsEnter
    .merge(groups)
      .attr('transform', (d, i) => 
            `translate(${width - 60}, ${(i * padding) + 150})`)
      .attr('opacity', d =>
            (!selectedColorValue || d === selectedColorValue)
            ? 1 : 0.2
           )
      .on('click', d => 
          (d === selectedColorValue)
          ? onClick(null) 
          : onClick(d));
  
  
  // Update Circles
  groupsEnter.append('circle')
    .merge(groups.select('circle'))
      .attr('r', circleRadius)
      .attr('fill', d => colorScale(d));
  
  // Update Circle Text
  groupsEnter.append('text')
    .merge(groups.select('text'))
      .text(d => d)
      .attr('dy', '0.32em')
      .attr('x', textOffset);
}
