import {
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format,
} from 'd3';


export const scatterPlot = (selection, props) => {
  const {
    data,
    title,
    xValue,
    yValue,
    xAxisLabel,
    yAxisLabel,
    circleRadius,
    selectedColorValue,
    colorScale,
    colorValue,
    width,
    height,
  } = props;
  
  const margin = { top: 60, right: 100, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  
  // Set Axis Scales
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  
  // Center Plot
  const g = selection.append('g')
    .attr('class', 'scatter')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  
  // Edit plot ticks and lines
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  xAxisG.select('.domain').remove();
  
  
  // Render Circles
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('opacity', d => 
            (!selectedColorValue || d.cylinders === selectedColorValue)
            ? 0.6
            : 0)
      .attr('fill', d => colorScale(d.cylinders))
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  
  // Set Y-Axis Label
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -93)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  // Set X-Axis Label
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  // Set Title
  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};